package com.quansu.alipay.utils

import android.app.Activity
import android.content.Context
import android.os.Handler
import android.os.Looper
import android.os.Message
import android.text.TextUtils
import android.widget.Toast
import com.alipay.sdk.app.PayTask
import com.hwangjr.rxbus.RxBus


/**
 *Created by shihuiyun
 *on 2020/12/21
 */
object PayUtils {
    private const val SDK_PAY_FLAG = 1
    private const val SDK_AUTH_FLAG = 2
    private var context: Context? = null


    private val mHandler = object : Handler(Looper.getMainLooper()) {

        override fun handleMessage(msg: Message) {
            super.handleMessage(msg)

            when (msg.what) {
                SDK_PAY_FLAG -> {

                    val payResult = PayResult(msg.obj as Map<String?, String?>)
                    /**
                     * 对于支付结果，请商户依赖服务端的异步通知结果。同步通知结果，仅作为支付结束的通知。
                     */
                    /**
                     * 对于支付结果，请商户依赖服务端的异步通知结果。同步通知结果，仅作为支付结束的通知。
                     */
                    // val resultInfo = payResult.result // 同步返回需要验证的信息

                    val resultStatus = payResult.resultStatus

                    // 判断resultStatus 为9000则代表支付成功
                    if (TextUtils.equals(resultStatus, "9000")) {
                        // 该笔订单是否真实支付成功，需要依赖服务端的异步通知。
                        //支付成功
                        RxBus.get().post("PAY_COMPLETE", "")

                    } else {
                        // 该笔订单真实的支付结果，需要依赖服务端的异步通知。
                        //
                        if (null != context) {
                            Toast.makeText(context, "支付失败", Toast.LENGTH_SHORT).show()
                        }

                    }

                }
                SDK_AUTH_FLAG -> {
                    val authResult = AuthResult(msg.obj as Map<String?, String?>, true)
                    val resultStatus: String = authResult.resultStatus
                    // 判断resultStatus 为“9000”且result_code
                    // 为“200”则代表授权成功，具体状态码代表含义可参考授权接口文档
                    if (TextUtils.equals(resultStatus, "9000") && TextUtils.equals(authResult.getResultCode(), "200")) {
                        // 获取alipay_open_id，调支付时作为参数extern_token 的value
                        // 传入，则支付账户为该授权账户
                        //认证成功
                    } else {
                        // 其他状态值则为授权失败
                        //认证失败
                    }


                }


            }


        }
    }


    //去支付
    fun toPay(orderInfo: String, context: Context) {

        this.context = context

        var payRunnable = Runnable {

            kotlin.run {
                var alipay = PayTask(context as Activity)
                val result = alipay.payV2(orderInfo, true)

                val msg = Message()
                msg.what = SDK_PAY_FLAG
                msg.obj = result
                mHandler.sendMessage(msg)
            }
        }

        // 必须异步调用
        val payThread = Thread(payRunnable)
        payThread.start()


    }

}
